Class: Google::Cloud::Functions::V2::Source

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/functions/v2/functions.rb

Overview

The location of the function source code.

Instance Attribute Summary collapse

Instance Attribute Details

#git_uri::String

Returns If provided, get the source from GitHub repository. This option is valid only for GCF 1st Gen function. Example: https://github.com///blob//

Note: The following fields are mutually exclusive: git_uri, storage_source, repo_source. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    If provided, get the source from GitHub repository. This option is valid only for GCF 1st Gen function. Example: https://github.com///blob//

    Note: The following fields are mutually exclusive: git_uri, storage_source, repo_source. If a field in that set is populated, all other fields in the set will automatically be cleared.



233
234
235
236
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 233

class Source
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#repo_source::Google::Cloud::Functions::V2::RepoSource

Returns If provided, get the source from this location in a Cloud Source Repository.

Note: The following fields are mutually exclusive: repo_source, storage_source, git_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Functions::V2::RepoSource)

    If provided, get the source from this location in a Cloud Source Repository.

    Note: The following fields are mutually exclusive: repo_source, storage_source, git_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.



233
234
235
236
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 233

class Source
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#storage_source::Google::Cloud::Functions::V2::StorageSource

Returns If provided, get the source from this location in Google Cloud Storage.

Note: The following fields are mutually exclusive: storage_source, repo_source, git_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Functions::V2::StorageSource)

    If provided, get the source from this location in Google Cloud Storage.

    Note: The following fields are mutually exclusive: storage_source, repo_source, git_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.



233
234
235
236
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 233

class Source
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end