Class: Google::Cloud::Functions::V2::BuildConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Functions::V2::BuildConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/functions/v2/functions.rb
Overview
Describes the Build step of the function that builds a container from the given source.
Defined Under Namespace
Modules: DockerRegistry Classes: EnvironmentVariablesEntry
Instance Attribute Summary collapse
-
#automatic_update_policy ⇒ ::Google::Cloud::Functions::V2::AutomaticUpdatePolicy
Note: The following fields are mutually exclusive:
automatic_update_policy,on_deploy_update_policy. -
#build ⇒ ::String
readonly
Output only.
-
#docker_registry ⇒ ::Google::Cloud::Functions::V2::BuildConfig::DockerRegistry
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#docker_repository ⇒ ::String
Repository in Artifact Registry to which the function docker image will be pushed after it is built by Cloud Build.
-
#entry_point ⇒ ::String
The name of the function (as defined in source code) that will be executed.
-
#environment_variables ⇒ ::Google::Protobuf::Map{::String => ::String}
User-provided build-time environment variables for the function.
-
#on_deploy_update_policy ⇒ ::Google::Cloud::Functions::V2::OnDeployUpdatePolicy
Note: The following fields are mutually exclusive:
on_deploy_update_policy,automatic_update_policy. -
#runtime ⇒ ::String
The runtime in which to run the function.
-
#service_account ⇒ ::String
Service account to be used for building the container.
-
#source ⇒ ::Google::Cloud::Functions::V2::Source
The location of the function source code.
-
#source_provenance ⇒ ::Google::Cloud::Functions::V2::SourceProvenance
readonly
Output only.
-
#worker_pool ⇒ ::String
Name of the Cloud Build Custom Worker Pool that should be used to build the function.
Instance Attribute Details
#automatic_update_policy ⇒ ::Google::Cloud::Functions::V2::AutomaticUpdatePolicy
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#build ⇒ ::String (readonly)
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#docker_registry ⇒ ::Google::Cloud::Functions::V2::BuildConfig::DockerRegistry
This field is deprecated and may be removed in the next major version update.
Returns Docker Registry to use for this deployment. This configuration is only
applicable to 1st Gen functions, 2nd Gen functions can only use Artifact
Registry.
Deprecated: As of March 2025, CONTAINER_REGISTRY option is no longer
available in response to Container Registry's deprecation:
https://cloud.google.com/artifact-registry/docs/transition/transition-from-gcr
Please use Artifact Registry instead, which is the default choice.
If unspecified, it defaults to ARTIFACT_REGISTRY.
If docker_repository field is specified, this field should either be left
unspecified or set to ARTIFACT_REGISTRY.
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#docker_repository ⇒ ::String
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#entry_point ⇒ ::String
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#environment_variables ⇒ ::Google::Protobuf::Map{::String => ::String}
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#on_deploy_update_policy ⇒ ::Google::Cloud::Functions::V2::OnDeployUpdatePolicy
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#runtime ⇒ ::String
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#service_account ⇒ ::String
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#source ⇒ ::Google::Cloud::Functions::V2::Source
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#source_provenance ⇒ ::Google::Cloud::Functions::V2::SourceProvenance (readonly)
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |
#worker_pool ⇒ ::String
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 336 class BuildConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvironmentVariablesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Docker Registry to use for storing function Docker images. module DockerRegistry # Unspecified. DOCKER_REGISTRY_UNSPECIFIED = 0 # Docker images will be stored in multi-regional Container Registry # repositories named `gcf`. CONTAINER_REGISTRY = 1 # Docker images will be stored in regional Artifact Registry repositories. # By default, GCF will create and use repositories named `gcf-artifacts` # in every region in which a function is deployed. But the repository to # use can also be specified by the user using the `docker_repository` # field. ARTIFACT_REGISTRY = 2 end end |