Class: Google::Cloud::Functions::V2::Function
- Inherits:
-
Object
- Object
- Google::Cloud::Functions::V2::Function
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/functions/v2/functions.rb
Overview
Describes a Cloud Function that contains user computation executed in response to an event. It encapsulates function and trigger configurations.
Defined Under Namespace
Modules: State Classes: LabelsEntry
Instance Attribute Summary collapse
-
#build_config ⇒ ::Google::Cloud::Functions::V2::BuildConfig
Describes the Build step of the function that builds a container from the given source.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
User-provided description of a function.
-
#environment ⇒ ::Google::Cloud::Functions::V2::Environment
Describe whether the function is 1st Gen or 2nd Gen.
-
#event_trigger ⇒ ::Google::Cloud::Functions::V2::EventTrigger
An Eventarc trigger managed by Google Cloud Functions that fires events in response to a condition in another service.
-
#kms_key_name ⇒ ::String
Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt function resources.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels associated with this Cloud Function.
-
#name ⇒ ::String
A user-defined name of the function.
-
#satisfies_pzs ⇒ ::Boolean
readonly
Output only.
-
#service_config ⇒ ::Google::Cloud::Functions::V2::ServiceConfig
Describes the Service being deployed.
-
#state ⇒ ::Google::Cloud::Functions::V2::Function::State
readonly
Output only.
-
#state_messages ⇒ ::Array<::Google::Cloud::Functions::V2::StateMessage>
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#url ⇒ ::String
readonly
Output only.
Instance Attribute Details
#build_config ⇒ ::Google::Cloud::Functions::V2::BuildConfig
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#description ⇒ ::String
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#environment ⇒ ::Google::Cloud::Functions::V2::Environment
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#event_trigger ⇒ ::Google::Cloud::Functions::V2::EventTrigger
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#kms_key_name ⇒ ::String
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#name ⇒ ::String
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#satisfies_pzs ⇒ ::Boolean (readonly)
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#service_config ⇒ ::Google::Cloud::Functions::V2::ServiceConfig
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#state ⇒ ::Google::Cloud::Functions::V2::Function::State (readonly)
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#state_messages ⇒ ::Array<::Google::Cloud::Functions::V2::StateMessage> (readonly)
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |
#url ⇒ ::String (readonly)
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'proto_docs/google/cloud/functions/v2/functions.rb', line 77 class Function include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Describes the current state of the function. module State # Not specified. Invalid state. STATE_UNSPECIFIED = 0 # Function has been successfully deployed and is serving. ACTIVE = 1 # Function deployment failed and the function is not serving. FAILED = 2 # Function is being created or updated. DEPLOYING = 3 # Function is being deleted. DELETING = 4 # Function deployment failed and the function serving state is undefined. # The function should be updated or deleted to move it out of this state. UNKNOWN = 5 end end |